<?php

namespace Pinpoint\LogoManager\Block;

use Magento\Cms\Model\Template\FilterProvider;
use Magento\Framework\View\Element\Template;
use Magento\Store\Model\StoreManagerInterface;

/**
 * Class Logo
 * @package Pinpoint\LogoManager\Block
 */
class Logo extends Template
{
    /**
     * @var string $_template
     */
    protected $_template = "Pinpoint_LogoManager::renderer.phtml";

    /**
     * @var \Pinpoint\LogoManager\Model\Logo
     */
    protected $logos;
    /**
     * @var FilterProvider
     */
    protected $filterProvider;
    /**
     * @var StoreManagerInterface
     */
    protected $storeManager;

    /**
     * Logo constructor.
     * @param Template\Context $context
     * @param \Pinpoint\LogoManager\Model\Logo $logos
     * @param FilterProvider $filterProvider
     * @param StoreManagerInterface $storeManager
     * @param array $data
     */
    public function __construct(
        Template\Context $context,
        \Pinpoint\LogoManager\Model\Logo $logos,
        FilterProvider $filterProvider,
        StoreManagerInterface $storeManager,
        array $data = []
    ) {
        $this->logos = $logos;
        $this->filterProvider = $filterProvider;
        $this->storeManager = $storeManager;

        parent::__construct($context, $data);
    }

    /**
     * @return \Magento\Framework\DataObject[]
     */
    public function getLogos()
    {
        $collection = $this->logos->getCollection()
            ->addFieldToFilter('is_active', \Pinpoint\LogoManager\Model\Logo::STATUS_ENABLED)
            ->setOrder('position', 'ASC');

        return $collection->getItems();
    }

    /**
     * Prepare Content HTML
     *
     * @return string
     */
    public function getWysiwygContent($content)
    {
        if(!empty($content)){
            $storeId = $this->storeManager->getStore()->getId();
            return $this->filterProvider->getBlockFilter()->setStoreId($storeId)->filter($content);
        }
        return null;
    }

    /**
     * @param $imageUrl
     * @return string
     */
    public function getImageUrl($imageUrl)
    {
        if (pathinfo(realpath($_SERVER["DOCUMENT_ROOT"]))['basename'] == 'pub') {
            return str_replace('pub/', '', $imageUrl);
        }

        return $imageUrl;
    }

}
