<?php
namespace Pinpoint\LogoManager\Model\Logo;
use Magento\Framework\UrlInterface;
use Magento\Store\Model\StoreManagerInterface;
use Pinpoint\LogoManager\Model\ResourceModel\Logo\CollectionFactory;
use Magento\Framework\App\Request\DataPersistorInterface;
use Magento\Framework\App\Filesystem\DirectoryList;
use Magento\Framework\Filesystem\Driver\File;

/**
 * Class DataProvider
 * @package Pinpoint\LogoManager\Model\Logo
 */
class DataProvider extends \Magento\Ui\DataProvider\AbstractDataProvider
{

    /**
     * @var \Pinpoint\LogoManager\Model\ResourceModel\Logo\Collection
     */
    protected $collection;

    /**
     * @var DataPersistorInterface
     */
    protected $dataPersistor;

    /**
     * @var array
     */
    protected $loadedData;

    /**
     * @var \Magento\Framework\Filesystem
     */
    protected $fileSystem;

    /**
     * @var StoreManagerInterface
     */
    protected $storeManager;

    /**
     * @param string $name
     * @param string $primaryFieldName
     * @param string $requestFieldName
     * @param CollectionFactory $collectionFactory
     * @param DataPersistorInterface $dataPersistor
     * @param Filesystem $fileSystem
     * @param File $fileDriver
     * @param StoreManagerInterface $storeManager
     * @param array $meta
     * @param array $data
     */
    public function __construct(
        $name,
        $primaryFieldName,
        $requestFieldName,
        CollectionFactory $collectionFactory,
        DataPersistorInterface $dataPersistor,
        \Magento\Framework\Filesystem $fileSystem,
        File $fileDriver,
        StoreManagerInterface $storeManager,
        array $meta = [],
        array $data = []
    ) {
        $this->collection = $collectionFactory->create();
        $this->dataPersistor = $dataPersistor;
        $this->fileSystem = $fileSystem;
        parent::__construct($name, $primaryFieldName, $requestFieldName, $meta, $data);
        $this->meta = $this->prepareMeta($this->meta);
        $this->storeManager = $storeManager;
        $this->fileDriver = $fileDriver;
    }

    /**
     * Prepares Meta
     *
     * @param array $meta
     * @return array
     */
    public function prepareMeta(array $meta)
    {
        return $meta;
    }

    /**
     * Get data
     *
     * @return array
     */
    public function getData()
    {
        if (isset($this->loadedData)) {
            return $this->loadedData;
        }
        $items = $this->collection->getItems();

        foreach ($items as $item) {
            $mediaUrl =  $this->storeManager->getStore()->getBaseUrl(UrlInterface::URL_TYPE_WEB);
            $filePath = $this->fileSystem->getDirectoryRead(DirectoryList::ROOT)->getAbsolutePath();
            $templateImage = $item->getData('logo');

            if (pathinfo(realpath($_SERVER["DOCUMENT_ROOT"]))['basename'] == 'pub') {
                $item->setData('logo', str_replace('pub/', '', $item->getData('logo')));
            }

            $item->setData('logo', [[
                'url' =>  $mediaUrl . $templateImage,
                'file' => $mediaUrl . $templateImage,
                'name' => basename($item->getData('logo')),
                'type' => $this->fileDriver->isExists($filePath . $templateImage) ? image_type_to_mime_type(exif_imagetype($mediaUrl . $templateImage)) : NULL,
                'size'=> $this->fileDriver->isExists($filePath . $templateImage) ? filesize($filePath . $templateImage) : NULL
            ]]);

            $this->loadedData[$item->getId()] = $item->getData();
        }

        $data = $this->dataPersistor->get('pinpoint_logomanager_logo');
        if (!empty($data)) {
            $item = $this->collection->getNewEmptyItem();
            $item->setData($data);
            $this->loadedData[$item->getId()] = $item->getData();
            $this->dataPersistor->clear('pinpoint_logomanager_logo');
        }

        return $this->loadedData;
    }
}
